@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -29,7 +29,6 @@
 
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineAccessKey>
-#include <WebEngineViewer/CheckPhishingUrlCache>
 #include <KPIMTextEdit/TextToSpeech>
 #include <KActionMenu>
 
@@ -58,6 +57,8 @@
 #include <WebEngineViewer/WebHitTest>
 #include <WebEngineViewer/WebEngineScript>
 
+#include <WebEngineViewer/LocalDataBaseManager>
+
 #include <KIO/KUriFilterSearchProviderActions>
 
 using namespace Akregator;
@@ -66,11 +67,12 @@ ArticleViewerWebEngine::ArticleViewerWebEngine(KActionCollection *ac, QWidget *p
     : WebEngineViewer::WebEngineView(parent),
       mActionCollection(ac),
       mLastButtonClicked(LeftButton),
-      mViewerPluginToolManager(Q_NULLPTR)
+      mViewerPluginToolManager(nullptr)
 {
     mNetworkAccessManager = new WebEngineViewer::InterceptorManager(this, ac, this);
     QWebEngineProfile *profile = new QWebEngineProfile(this);
     mPageEngine = new ArticleViewerWebEnginePage(profile, this);
+    profile->setPersistentCookiesPolicy(QWebEngineProfile::NoPersistentCookies);
 
     setPage(mPageEngine);
 
@@ -97,6 +99,9 @@ ArticleViewerWebEngine::ArticleViewerWebEngine(KActionCollection *ac, QWidget *p
     connect(page(), &QWebEnginePage::recentlyAudibleChanged,
             this, &ArticleViewerWebEngine::slotWebPageMutedOrAudibleChanged);
 #endif
+
+    connect(WebEngineViewer::LocalDataBaseManager::self(), &WebEngineViewer::LocalDataBaseManager::checkUrlFinished, this, &ArticleViewerWebEngine::slotCheckedUrlFinished);
+
 }
 
 ArticleViewerWebEngine::~ArticleViewerWebEngine()
@@ -130,7 +135,7 @@ void ArticleViewerWebEngine::paintAboutScreen(const QString &templateName, const
 {
     GrantleeTheme::ThemeManager manager(QStringLiteral("splashPage"),
                                         QStringLiteral("splash.theme"),
-                                        Q_NULLPTR,
+                                        nullptr,
                                         QStringLiteral("messageviewer/about/"));
     GrantleeTheme::Theme theme = manager.theme(QStringLiteral("default"));
     if (theme.isValid()) {
@@ -371,29 +376,28 @@ bool ArticleViewerWebEngine::urlIsAMalwareButContinue()
     return true;
 }
 
-void ArticleViewerWebEngine::slotCheckPhishingUrlResult(WebEngineViewer::CheckPhishingUrlJob::UrlStatus status, const QUrl &url)
+void ArticleViewerWebEngine::slotCheckedUrlFinished(const QUrl &url, WebEngineViewer::CheckPhishingUrlUtil::UrlStatus status)
 {
     switch (status) {
-    case WebEngineViewer::CheckPhishingUrlJob::BrokenNetwork:
+    case WebEngineViewer::CheckPhishingUrlUtil::BrokenNetwork:
         KMessageBox::error(this, i18n("The network is broken."), i18n("Check Phishing Url"));
         break;
-    case WebEngineViewer::CheckPhishingUrlJob::InvalidUrl:
+    case WebEngineViewer::CheckPhishingUrlUtil::InvalidUrl:
         KMessageBox::error(this, i18n("The url %1 is not valid.", url.toString()), i18n("Check Phishing Url"));
         break;
-    case WebEngineViewer::CheckPhishingUrlJob::Ok:
-        WebEngineViewer::CheckPhishingUrlCache::self()->setCheckingUrlResult(url, true);
+    case WebEngineViewer::CheckPhishingUrlUtil::Ok:
         break;
-    case WebEngineViewer::CheckPhishingUrlJob::MalWare:
-        WebEngineViewer::CheckPhishingUrlCache::self()->setCheckingUrlResult(url, false);
+    case WebEngineViewer::CheckPhishingUrlUtil::MalWare:
         if (!urlIsAMalwareButContinue()) {
             return;
         }
         break;
-    case WebEngineViewer::CheckPhishingUrlJob::Unknown:
-        qCWarning(AKREGATOR_LOG) << "WebEngineViewer::CheckPhishingUrlJob unknown error ";
+    case WebEngineViewer::CheckPhishingUrlUtil::Unknown:
+        qCWarning(AKREGATOR_LOG) << "ArticleViewerWebEngine::slotCheckedUrlFinished unknown error ";
         break;
     }
     openSafeUrl(url);
+
 }
 
 void ArticleViewerWebEngine::slotLinkClicked(const QUrl &url)
@@ -402,19 +406,7 @@ void ArticleViewerWebEngine::slotLinkClicked(const QUrl &url)
         return;
     }
     if (Settings::checkPhishingUrl()) {
-        const WebEngineViewer::CheckPhishingUrlCache::UrlStatus status = WebEngineViewer::CheckPhishingUrlCache::self()->urlStatus(url);
-        if (status == WebEngineViewer::CheckPhishingUrlCache::UrlOk) {
-            openSafeUrl(url);
-        } else if (status == WebEngineViewer::CheckPhishingUrlCache::MalWare) {
-            if (!urlIsAMalwareButContinue()) {
-                return;
-            }
-        } else {
-            WebEngineViewer::CheckPhishingUrlJob *job = new WebEngineViewer::CheckPhishingUrlJob(this);
-            connect(job, &WebEngineViewer::CheckPhishingUrlJob::result, this, &ArticleViewerWebEngine::slotCheckPhishingUrlResult);
-            job->setUrl(url);
-            job->start();
-        }
+        WebEngineViewer::LocalDataBaseManager::self()->checkUrl(url);
     } else {
         openSafeUrl(url);
     }
@@ -452,7 +444,6 @@ void ArticleViewerWebEngine::openSafeUrl(const QUrl &url)
     Q_EMIT signalOpenUrlRequest(req);
 }
 
-
 void ArticleViewerWebEngine::slotOpenLinkInForegroundTab()
 {
     OpenUrlRequest req(mCurrentUrl);
@@ -482,7 +473,7 @@ void ArticleViewerWebEngine::createViewerPluginToolManager(KActionCollection *ac
     mViewerPluginToolManager->setPluginName(QStringLiteral("akregator"));
     mViewerPluginToolManager->setServiceTypeName(QStringLiteral("Akregator/ViewerPlugin"));
     if (!mViewerPluginToolManager->initializePluginList()) {
-        qDebug() << " Impossible to initialize plugins";
+        qCWarning(AKREGATOR_LOG) << " Impossible to initialize plugins";
     }
     mViewerPluginToolManager->createView();
     connect(mViewerPluginToolManager, &MessageViewer::ViewerPluginToolManager::activatePlugin, this, &ArticleViewerWebEngine::slotActivatePlugin);
