@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ using namespace Akregator;
 
 MainFrame::MainFrame(QWidget *parent, QWidget *visibleWidget)
     : Frame(parent),
-      mArticleViewer(Q_NULLPTR)
+      mArticleViewer(nullptr)
 {
     setRemovable(false);
     QGridLayout *layout = new QGridLayout(this);
