@@ -36,7 +36,7 @@
 
 #include <QAbstractItemView>
 #include <QMenu>
-
+#include <memory>
 using namespace Akregator;
 
 namespace
@@ -55,7 +55,7 @@ static Akregator::Article articleForIndex(const QModelIndex &index, FeedList *fe
 static QVector<Akregator::Article> articlesForIndexes(const QModelIndexList &indexes, FeedList *feedList)
 {
     QVector<Akregator::Article> articles;
-    Q_FOREACH (const QModelIndex &i, indexes) {
+    for (const QModelIndex &i : indexes) {
         const Article a = articleForIndex(i, feedList);
         if (a.isNull()) {
             continue;
@@ -69,7 +69,7 @@ static QVector<Akregator::Article> articlesForIndexes(const QModelIndexList &ind
 static Akregator::TreeNode *subscriptionForIndex(const QModelIndex &index, Akregator::FeedList *feedList)
 {
     if (!index.isValid()) {
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     return feedList->findByID(index.data(Akregator::SubscriptionListModel::SubscriptionIdRole).toInt());
@@ -177,7 +177,7 @@ void Akregator::SelectionController::setFeedList(const QSharedPointer<FeedList>
     }
 
     m_feedList = list;
-    QScopedPointer<SubscriptionListModel> oldModel(m_subscriptionModel);
+    std::unique_ptr<SubscriptionListModel> oldModel(m_subscriptionModel);
     m_subscriptionModel = new SubscriptionListModel(m_feedList, this);
 
     if (m_folderExpansionHandler) {
